@@ -20,7 +20,7 @@
 #include "knutvardata.h"
 #include "knutnet.h"
 
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kapp.h>
 
 #include <tqtooltip.h>
